print.onls: Printing function for 'onls' objects

View source: R/S3_functions.R

print.onlsR Documentation

Printing function for 'onls' objects

Description

Provides a printed summary of the converged fit obtained from onls.

Usage

## S3 method for class 'onls'
print(x, ...)

Arguments

x

an object returned from onls.

...

other parameters for future methods.

Value

A printed summary containing the formula, data name, converged parameters, vertical residual sum-of-squares

\sum_{i=1}^{n} w_i (y_i - \hat{y_i})^2

(prefixed “weighted” when weights are non-constant), orthogonal residual sum-of-squares

\sum_{i=1}^{n} \hat d_i^2

(see onls for the general, precision-weighted definition of \hat d_i; plain Euclidean distance is a special case), a “PASSED”/“FAILED” message reporting how many fitted points are orthogonal as obtained from check_o, and the number of iterations to convergence.

Author(s)

Andrej-Nikolai Spiess

Examples

## See 'onls'.

onls documentation built on Sept. 21, 2026, 9:06 a.m.