| print.onls | R Documentation |
Provides a printed summary of the converged fit obtained from onls.
## S3 method for class 'onls'
print(x, ...)
x |
an object returned from |
... |
other parameters for future methods. |
A printed summary containing the formula, data name, converged parameters, vertical residual sum-of-squares
\sum_{i=1}^{n} w_i (y_i - \hat{y_i})^2
(prefixed “weighted” when weights are non-constant), orthogonal residual sum-of-squares
\sum_{i=1}^{n} \hat d_i^2
(see onls for the general, precision-weighted definition of \hat d_i; plain Euclidean distance is a special case), a “PASSED”/“FAILED” message reporting how many fitted points are orthogonal as obtained from check_o, and the number of iterations to convergence.
Andrej-Nikolai Spiess
## See 'onls'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.