Learn R Programming

onls (version 0.1-1)

print.onls: Printing function for 'onls' objects

Description

Provides a printed summary of the converged fit obtained from onls.

Usage

## S3 method for class 'onls':
print(x, ...)

Arguments

x
an object returned from onls.
...
other parameters for future methods.

Value

  • A printed summary containing the formula, data name, converged parameters, vertical residual sum-of-squares $$\sum_{i=1}^{n}(y_i - \hat{y_i})^2$$, orthogonal residual sum-of-squares $$\sum_{i=1}^{n}\| D_i \|^2$$, number of points with orthogonality as obtained from check_o and number of iterations to convergence.

Examples

Run this code
## See 'onls'.

Run the code above in your browser using DataLab