Learn R Programming

onls (version 0.2)

print.onls: Printing function for 'onls' objects

Description

Provides a printed summary of the converged fit obtained from onls.

Usage

# S3 method for onls
print(x, ...)

Value

A printed summary containing the formula, data name, converged parameters, vertical residual sum-of-squares $$\sum_{i=1}^{n} w_i (y_i - \hat{y_i})^2$$ (prefixed “weighted” when weights are non-constant), orthogonal residual sum-of-squares $$\sum_{i=1}^{n} \hat d_i^2$$ (see onls for the general, precision-weighted definition of \(\hat d_i\); plain Euclidean distance is a special case), a “PASSED”/“FAILED” message reporting how many fitted points are orthogonal as obtained from check_o, and the number of iterations to convergence.

Arguments

x

an object returned from onls.

...

other parameters for future methods.

Author

Andrej-Nikolai Spiess

Examples

Run this code
## See 'onls'.

Run the code above in your browser using DataLab